this.name           = "HyperspaceHangar";
this.author         = "Kenji Takashima";
this.copyright      = "(C) 2015 Kenji Takashima.";
this.licence        = "CC-BY-NC-SA 3.0";
this.description    = "Provides a hangar for your ships across the stars.";
this.version        = "1.3.0";

"use strict";

this.startUpComplete = function()
{
    if (!missionVariables.hyperSpace_shipsStored)
    { //first time setup
	missionVariables.hyperSpace_namesStored = JSON.stringify({"1_EXIT": "EMPTY"});  
	missionVariables.hyperSpace_shipsStored = JSON.stringify({});
	missionVariables.hyperSpace_priceOption = 250000;
	missionVariables.hyperSpace_timeOption = 1800;
    } 
    
    //names of ships stored. Used because _shipsStored would give JSON strings 
    this._currentNames = JSON.parse(missionVariables.hyperSpace_namesStored);
    
    //values of ships stored.
    this._shipsStored = JSON.parse(missionVariables.hyperSpace_shipsStored);
    
    this._shipTempKey = 0;
    this._shipPrice = 0;
    this._bought = 0;
    this._actuallyBought = 0;
    this._priceOption =  missionVariables.hyperSpace_priceOption;
    this._timeOption = missionVariables.hyperSpace_timeOption;
    
    this.$dockedCheck();
}

this.shipDockedWithStation = function()
{
    this.$dockedCheck();
    this.playerWillSaveGame();
}

//save variables for next time
this.playerWillSaveGame = function() 
{
    missionVariables.hyperSpace_namesStored = JSON.stringify(this._currentNames);
    missionVariables.hyperSpace_shipsStored = JSON.stringify(this._shipsStored);
    missionVariables.hyperSpace_priceOption = this._priceOption;
    missionVariables.hyperSpace_timeOption = this._timeOption;
}

//create hangar interface if docked.
this.$dockedCheck = function()
{		
    if (player.ship.docked)
    {
	player.ship.dockedStation.setInterface("HyperSpace",
		{ title: "Hyperspace Hangar",
		  category: "Services",
		  summary: "Stores ships.",
		  callback: this.$storeShips.bind(this) });
    }
}

//store player's ship if replacement is a possibility.
this.guiScreenChanged = function(to, from)
{
    if (to == "GUI_SCREEN_SHIPYARD")
    {
	this._shipsStored[clock.absoluteSeconds] = worldScripts["Ship_Storage_Helper.js"].storeCurrentShip();
	this._currentNames[clock.absoluteSeconds] = player.ship.displayName;
	this._shipTempKey = clock.absoluteSeconds;
	this._shipPrice = player.ship.price;
	this._bought = 0;
	this._actuallyBought = 1;
    }	    
}

this.guiScreenWillChange = function()
{
    if (to != "GUI_SCREEN_SHIPYARD")
    {
	if (this._bought != 1)
	{
	    delete this._shipsStored[this._shipTempKey];
	    delete this._currentNames[this._shipTempKey];
	}
	this._actuallyBought = 0;
    }
}


//Activate hangar.
this.playerBoughtNewShip = function()
{
    if (player.credits - (this._shipPrice + player.ship.price) < this._priceOptio && this._actuallyBought == 1)
    {
	this._bought = 0;
	this._actuallyBought = 0;
	return;
    }
    else if (this._actuallyBought == 1)
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Store ship?",
	    choicesKey: "hyperSpace_askstore"},
			  this.$askStore);
	mission.addMessageText("Current price: " + (this._priceOption / 10) + " Cr.");
	mission.addMessageText("Current storage time: " + (this._timeOption / 60) + " Minutes.");
    }
    this._actuallyBought = 0;
    this._bought = 1;
}

//storing a ship costs time and money, removing handwavium
this.$askStore = function(choice) 
{
    if (choice == "1_STORE")
    {
	if (player.credits >= (this._priceOption))
	{
	    this._currentNames["1_EXIT"] = "Exit.";
	    player.consoleMessage("Previous ship stored.");
	    player.credits = player.credits - this._priceOption;
	    clock.addSeconds(this._timeOption); 
	}
    }
    else
    {
	return;
    }
}
//hangar function proper
this.$storeShips = function()
{
    //not activated unless another ship is bought
    if (this._currentNames["1_EXIT"] == "EMPTY")
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "No ships stored.",
	    choicesKey: "hyperSpace_notstored"},
			  this.$noneStored);
    } 
    else
    { 
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Choose an option.",
	    choicesKey: "hyperSpace_choices"},
			  this.$choice);
    }
}

this.$choice = function(choice)
{
    if (choice == "GARAGE_1_SWITCH")
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Choose a ship.",
	    choices: (this._currentNames)},
			  this.$choice_switch);
	mission.addMessageText("Current storage time: " + (this._timeOption / 60) + " Minutes.");
	
    }
    
    else if (choice == "GARAGE_2_SELL")
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Choose a replacement ship.",
	    choices: (this._currentNames)},
			  this.$choice_sell);
	mission.addMessageText("Current selling time: " + (this._timeOption / 60) + " Minutes.");
    }
    else if (choice == "GARAGE_3_OPTIONS")
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Choose a replacement ship.",
	    choicesKey: "hyperSpace_options"},
			  this.$choice_options);
    }
    else
    {
	return;
    }
}


this.$choice_switch = function(choice)
{
    //give chance to exit. ditto for sell function.
    if (choice == "1_EXIT")
    {
	return;
    }
    //store ship, delete taken out ship's data
    this._shipsStored[clock.absoluteSeconds] = worldScripts["Ship_Storage_Helper.js"].storeCurrentShip();
    this._currentNames[clock.absoluteSeconds] = player.ship.displayName;
    this._shipTempKey = clock.absoluteSeconds;
    worldScripts["Ship_Storage_Helper.js"].restoreStoredShip(this._shipsStored[choice]);
    delete this._shipsStored[choice];
    delete this._currentNames[choice];
    clock.addSeconds(this._timeOption);
}


this.$choice_sell = function(choice)
{
    if (choice == "1_EXIT")
    {
	return;
    }
    //"sell" ship
    player.credits = player.credits + (player.ship.price * .75);
    delete this._shipsStored[this._shipTempKey];
    delete this._currentNames[this._shipTempKey];
    worldScripts["Ship_Storage_Helper.js"].restoreStoredShip(this._shipsStored[choice]);
    delete this._shipsStored[choice];
    delete this._currentNames[choice];
    clock.addSeconds(this._timeOption);
    //deactivate hangar if empty
    if (Object.keys(this._currentNames) == "1_EXIT")
    {
	this._currentNames["1_EXIT"] = "EMPTY";
    }
}

this.$choice_options = function(choice)
{
    if (choice == "1_PRICE")
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Input price",
	    textEntry: "TRUE"},
			  this.$choice_price);
    }
    else if (choice == "2_TIME")
    {
	mission.runScreen({
	    title: "Hyperspace Hangar",
	    message: "Input time",
	    textEntry: "TRUE"},
			  this.$choice_time);
    }
    else
    {
	return;
    }
}

this.$choice_price = function(choice)
{
    this._priceOption = choice * 10;
}

this.$choice_time = function(choice)
{
    this._timeOption = choice;
}

this.$noneStored = function(choice)
{
    if (choice == "1_EXIT")
    {
	return;
    }
}

 
